@@ -65,7 +65,7 @@ public:
 	}
 };
 
-class KDE_EXPORT OTRPlugin : public Kopete::Plugin
+class TDE_EXPORT OTRPlugin : public Kopete::Plugin
 {
 	TQ_OBJECT
 
