@@ -29,7 +29,7 @@ class VerifyPopup : public VerifyPopupUI
   TQ_OBJECT
 
 public:
-  VerifyPopup(TQWidget* parent = 0, const char* name = 0, Kopete::ChatSession *session = NULL, bool modal = FALSE, WFlags fl = 0 );
+  VerifyPopup(TQWidget* parent = 0, const char* name = 0, Kopete::ChatSession *session = NULL, bool modal = false, WFlags fl = 0 );
   ~VerifyPopup();
   /*$PUBLIC_FUNCTIONS$*/
 
